﻿var Tree = {};

Tree.NONE = '';
Tree.RED = 'red';
Tree.YELLOW = 'yellow';
Tree.PINK = 'pink';
Tree.BLUE = 'blue';
Tree.MIX = 'mix';

Tree.TOP_STYLE_KEY = 'top_style';
Tree.TOP_COLOR_KEY = 'top_color';

Tree.BALLS_COLOR_KEY = 'balls_color';
Tree.BALLS_AMOUNT_KEY = 'balls_amount';

Tree.LIGHTS_COLOR_KEY = 'lights_color';
Tree.LIGHTS_AMOUNT_KEY = 'lights_amount';

Tree.BOWS_COLOR_KEY = 'bows_color';
Tree.STOCKINGS_COLOR_KEY = 'stockings_color';

Tree.STAR = 'star';
Tree.BOW = 'bow';

Tree.FEW = '1';
Tree.MORE = '2';
Tree.LOT_MORE = '3';

Tree.LIGHTS_ON = 0;
Tree.LIGHTS_OFF = 1;

Tree.getTopImage = function() {
  if (!options.getValue(Tree.TOP_STYLE_KEY)) {
    return '';
  }
  return 'top_' + options.getValue(Tree.TOP_STYLE_KEY) + '_' + options.getValue(Tree.TOP_COLOR_KEY) + '.png';
};

Tree.getBallsImage = function() {
  if (!options.getValue(Tree.BALLS_COLOR_KEY)) {
    return '';
  }
  return 'ball_' + options.getValue(Tree.BALLS_COLOR_KEY) + '_' + options.getValue(Tree.BALLS_AMOUNT_KEY) + '.png';
};

Tree.getLightsImage = function(state) {
  if (!options.getValue(Tree.LIGHTS_COLOR_KEY)) {
    return '';
  }

  if (state == Tree.LIGHTS_OFF) {
    return 'light_' + options.getValue(Tree.LIGHTS_COLOR_KEY) + '_' + options.getValue(Tree.LIGHTS_AMOUNT_KEY) + '_off.png';	
  }  
  
  return 'light_' + options.getValue(Tree.LIGHTS_COLOR_KEY) + '_' + options.getValue(Tree.LIGHTS_AMOUNT_KEY) + '.png';
};

Tree.getBowsImage = function() {
  if (!options.getValue(Tree.BOWS_COLOR_KEY)) {
    return '';
  }
  return 'bow_' + options.getValue(Tree.BOWS_COLOR_KEY) + '.png' ;
};

Tree.getStockingsImage = function() {
  if (!options.getValue(Tree.STOCKINGS_COLOR_KEY)) {
    return '';
  }
  return 'stocking_' + options.getValue(Tree.STOCKINGS_COLOR_KEY) + '.png';
};


var View = {};

View.lightState = Tree.LIGHTS_ON;
View.blinkTimer = null;

View.onOpen = function() {
  options.defaultValue(Tree.TOP_STYLE_KEY) = Tree.STAR;
  options.defaultValue(Tree.TOP_COLOR_KEY) = Tree.YELLOW;
  options.defaultValue(Tree.BALLS_COLOR_KEY) = Tree.RED;
  options.defaultValue(Tree.BALLS_AMOUNT_KEY) = Tree.FEW;
  options.defaultValue(Tree.LIGHTS_COLOR_KEY) = Tree.YELLOW;
  options.defaultValue(Tree.LIGHTS_AMOUNT_KEY) = Tree.MORE;
  options.defaultValue(Tree.BOWS_COLOR_KEY) = Tree.MIX;
  options.defaultValue(Tree.STOCKINGS_COLOR_KEY) = Tree.MIX;
    
  plugin.onAddCustomMenuItems = View.onAddCustomMenuItems;
  View.draw();
};

View.onAddCustomMenuItems = function(menu) {
  var top = menu.AddPopup(strings.TOP);
  var isTopNone = options(Tree.TOP_STYLE_KEY) == Tree.NONE;
  Utils.addMenuOption(top, strings.NONE, Tree.NONE, Tree.TOP_STYLE_KEY);
  Utils.addMenuOption(top, strings.STAR, Tree.STAR, Tree.TOP_STYLE_KEY);
  Utils.addMenuOption(top, strings.BOW, Tree.BOW, Tree.TOP_STYLE_KEY);
  Utils.addMenuSeparator(top);
  Utils.addMenuOption(top, strings.RED, Tree.RED, Tree.TOP_COLOR_KEY, isTopNone);
  Utils.addMenuOption(top, strings.YELLOW, Tree.YELLOW, Tree.TOP_COLOR_KEY, isTopNone);
  Utils.addMenuOption(top, strings.PINK, Tree.PINK, Tree.TOP_COLOR_KEY, isTopNone);
  Utils.addMenuOption(top, strings.BLUE, Tree.BLUE, Tree.TOP_COLOR_KEY, isTopNone);

  var balls = menu.AddPopup(strings.BALLS);
  var isBallsNone = options(Tree.BALLS_COLOR_KEY) == Tree.NONE;
  Utils.addMenuOption(balls, strings.NONE, Tree.NONE, Tree.BALLS_COLOR_KEY);
  Utils.addMenuOption(balls, strings.RED, Tree.RED, Tree.BALLS_COLOR_KEY);
  Utils.addMenuOption(balls, strings.YELLOW, Tree.YELLOW, Tree.BALLS_COLOR_KEY);
  Utils.addMenuOption(balls, strings.PINK, Tree.PINK, Tree.BALLS_COLOR_KEY);
  Utils.addMenuOption(balls, strings.BLUE, Tree.BLUE, Tree.BALLS_COLOR_KEY);
  Utils.addMenuOption(balls, strings.MIX, Tree.MIX, Tree.BALLS_COLOR_KEY);
  Utils.addMenuSeparator(balls);
  Utils.addMenuOption(balls, strings.A_FEW, Tree.FEW, Tree.BALLS_AMOUNT_KEY, isBallsNone);
  Utils.addMenuOption(balls, strings.MORE, Tree.MORE, Tree.BALLS_AMOUNT_KEY, isBallsNone);
  Utils.addMenuOption(balls, strings.A_LOT_MORE, Tree.LOT_MORE, Tree.BALLS_AMOUNT_KEY, isBallsNone);

  var lights = menu.AddPopup(strings.LIGHTS);
  var isLightsNone = options(Tree.LIGHTS_COLOR_KEY) == Tree.NONE;
  Utils.addMenuOption(lights, strings.NONE, Tree.NONE, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuOption(lights, strings.RED, Tree.RED, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuOption(lights, strings.YELLOW, Tree.YELLOW, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuOption(lights, strings.PINK, Tree.PINK, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuOption(lights, strings.BLUE, Tree.BLUE, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuOption(lights, strings.MIX, Tree.MIX, Tree.LIGHTS_COLOR_KEY);
  Utils.addMenuSeparator(lights);
  Utils.addMenuOption(lights, strings.A_FEW, Tree.FEW, Tree.LIGHTS_AMOUNT_KEY, isLightsNone);
  Utils.addMenuOption(lights, strings.MORE, Tree.MORE, Tree.LIGHTS_AMOUNT_KEY, isLightsNone);
  Utils.addMenuOption(lights, strings.A_LOT_MORE, Tree.LOT_MORE, Tree.LIGHTS_AMOUNT_KEY, isLightsNone);

  var bows = menu.AddPopup(strings.BOWS);
  Utils.addMenuOption(bows, strings.NONE, Tree.NONE, Tree.BOWS_COLOR_KEY);
  Utils.addMenuOption(bows, strings.RED, Tree.RED, Tree.BOWS_COLOR_KEY);
  Utils.addMenuOption(bows, strings.YELLOW, Tree.YELLOW, Tree.BOWS_COLOR_KEY);
  Utils.addMenuOption(bows, strings.PINK, Tree.PINK, Tree.BOWS_COLOR_KEY);
  Utils.addMenuOption(bows, strings.BLUE, Tree.BLUE, Tree.BOWS_COLOR_KEY);
  Utils.addMenuOption(bows, strings.MIX, Tree.MIX, Tree.BOWS_COLOR_KEY);
  
  var stockings = menu.AddPopup(strings.STOCKINGS);
  Utils.addMenuOption(stockings, strings.NONE, Tree.NONE, Tree.STOCKINGS_COLOR_KEY);
  Utils.addMenuOption(stockings, strings.RED, Tree.RED, Tree.STOCKINGS_COLOR_KEY);
  Utils.addMenuOption(stockings, strings.YELLOW, Tree.YELLOW, Tree.STOCKINGS_COLOR_KEY);
  Utils.addMenuOption(stockings, strings.PINK, Tree.PINK, Tree.STOCKINGS_COLOR_KEY);
  Utils.addMenuOption(stockings, strings.BLUE, Tree.BLUE, Tree.STOCKINGS_COLOR_KEY);
  Utils.addMenuOption(stockings, strings.MIX, Tree.MIX, Tree.STOCKINGS_COLOR_KEY);
};


View.onOptionChanged = function() {
  View.draw();
};

View.draw = function() {
//  gadget.debug.trace(View.lightState);
  topImage.src = Tree.getTopImage();
  ballsImage.src = Tree.getBallsImage();
  lightsImage.src = Tree.getLightsImage(View.lightState);
  bowsImage.src = Tree.getBowsImage();
  stockingsImage.src = Tree.getStockingsImage();
};

View.startBlinkLights = function() {
  View.blinkTimer = view.setInterval(View.blinkLights, 500);
};

View.blinkLights = function() {
  ++View.lightState;
  
  if (View.lightState > Tree.LIGHTS_OFF) {
    View.lightState = Tree.LIGHTS_ON;
  }

  View.draw();
};

View.stopBlinkLights = function() {
  if (View.blinkTimer) {
    view.clearInterval(View.blinkTimer);
  }
  View.lightState = Tree.LIGHTS_ON;
  View.draw();
};

View.onMouseOver = function() {
  View.startBlinkLights();
};

View.onMouseOut = function() {
  View.stopBlinkLights();
};


var Utils = {};

Utils.addMenuOption = function(menu, label, value, optionsKey, disabled) {
  var flags = (options.getValue(optionsKey) == value) ? gddMenuItemFlagChecked : 0;

  if (disabled) {
    flags |= gddMenuItemFlagGrayed;
  }

  menu.AddItem(label, flags, function() { options.putValue(optionsKey, value); });
};

Utils.addMenuSeparator = function(menu) {
  menu.AddItem('', 0, undefined);
};
